CountryPickerHelper class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
countryJsonList
→ List<
Map< String, String> > -
final
-
countryList
→ List<
CountryModel> -
final
- packageName → String
-
final
Static Methods
-
getByCallingCode(
String callingCode, {List< CountryModel> ? allowedCountryList}) → CountryModel? -
getByCountryCode(
String code, {List< CountryModel> ? allowedCountryList}) → CountryModel? -
getByName(
String name, {List< CountryModel> ? allowedCountryList}) → CountryModel? -
getListByQuery(
String query, {List< CountryModel> ? allowedCountryList}) → List<CountryModel>